%global upstream_name postorius

Name:           postorius
Version:        1.0.2
Release:        0.5%{?dist}
Summary:        Web user interface for GNU Mailman

License:        GPLv3
URL:            https://launchpad.net/postorius
#Source0:        https://pypi.python.org/packages/source/p/%{upstream_name}/%{upstream_name}-%{version}.tar.gz
Source0:        %{upstream_name}-%{version}dev.tar.gz

# To get SOURCE1:
#   git clone https://gitlab.com/mailman/postorius_standalone.git
#   tar -cf postorius_standalone-%{version}.tar.gz --exclude .git postorius_standalone
Source1:        postorius_standalone-%{version}.tar.gz

Source2:        postorius.apache.conf

# The python-django package installs django-admin.py as django-admin
Patch0:         postorius-toxini.patch
# Merge requests pending
Patch10:        %{name}-link-existing-address.patch


BuildArch:      noarch

BuildRequires:  python-devel
BuildRequires:  python-sphinx
BuildRequires:  python-mailman-client
BuildRequires:  python-django >= 1.6
BuildRequires:  python-django-south
BuildRequires:  django-browserid
# for the unit tests
BuildRequires:  python-tox >= 1.7.0
BuildRequires:  python-mock
BuildRequires:  postfix
#BuildRequires:  python-django-nose
BuildRequires:  python-vcrpy

Requires:       python-mailman-client
Requires:       python-django >= 1.6
Requires:       django-browserid


%description
The Postorius Django app provides a web user interface to access GNU Mailman.

%prep
%setup -q -n %{upstream_name}-%{version}dev -a 1
%patch0 -p0
%patch10 -p1

# Remove bundled egg-info
rm -rf src/%{upstream_name}.egg-info
# remove shebang on manage.py
#sed -i -e '1d' postorius_standalone/manage.py
# remove executable permissions on wsgi script
chmod -x postorius_standalone/srv/postorius.wsgi
# remove __init__.py in postorius_standalone to prevent it from being
# installed (find_package won't find it). It's empty anyway.
rm -f postorius_standalone/__init__.py


%build
%{__python} setup.py build

# generate html docs
sphinx-build src/postorius/doc html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}


%install
rm -rf %{buildroot}
%{__python} setup.py install --skip-build --root %{buildroot}

# Install the Django files
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/sites/default
cp -p postorius_standalone/{manage,settings,urls}.py \
    %{buildroot}%{_sysconfdir}/%{name}/sites/default/
touch --reference postorius_standalone/manage.py \
    %{buildroot}%{_sysconfdir}/%{name}/sites/default/__init__.py
cp -pr postorius_standalone/srv %{buildroot}%{_sysconfdir}/%{name}/sites/default/
# Apache HTTPd config file
install -p -D -m 644 %{SOURCE2} %{buildroot}/%{_sysconfdir}/httpd/conf.d/postorius.conf
# Localstate directory
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/sites/default/static
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/sites/default/db
# Remove the doc from the site-packages dir
rm -rf %{python_sitelib}/%{name}/doc


%check
#DJANGO_VER=$(rpm -q --qf '%{V}' python-django | sed -r -e 's/^([0-9]+)\.([0-9]+)\.[0-9]+$/\1\2/')
#tox --sitepackages -e py27-django${DJANGO_VER}
PYTHONPATH=`pwd`:`pwd`/src %{_bindir}/django-admin test --settings=testing.test_settings postorius


%post
# Build the static files cache
%{_bindir}/django-admin collectstatic \
    --pythonpath=%{_sysconfdir}/%{name}/sites/default \
    --settings=settings --noinput >/dev/null || :


%preun
# The static files are a cache and can be removed with the package
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    rm -rf %{_localstatedir}/lib/%{name}/sites/default/static
fi


%files
%doc html README.rst COPYING
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/httpd/conf.d/postorius.conf
%{python_sitelib}/%{name}
%{python_sitelib}/%{upstream_name}-*-py?.?.egg-info
%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/sites
%dir %{_localstatedir}/lib/%{name}/sites/default
%dir %{_localstatedir}/lib/%{name}/sites/default/static
%attr(755,apache,apache) %{_localstatedir}/lib/%{name}/sites/default/db


%changelog
* Wed Apr 29 2015 Aurelien Bompard <abompard@fedoraproject.org> - 1.0.1-1
- version 1.0.1

* Wed Jul 24 2013 Aurelien Bompard <abompard@fedoraproject.org> - 1.0.0-0.5.bzr147
- update to BZR rev 147
- drop patch 0

* Wed Mar 27 2013 Aurelien Bompard <abompard@fedoraproject.org> - 1.0.0-0.1.a1
- initial package
